@@ -33,6 +33,7 @@ import copy
 import gobject
 import pango
 import pycentrino_globals as pglobals
+import gc
 
 class pycentrinoApplet(gnome.applet.Applet):
         
@@ -85,6 +86,9 @@ class pycentrinoApplet(gnome.applet.Applet):
             for i in (self.box.get_children()):
                 self.box.remove(i)
 
+            # added to prevent memory leaks
+            gc.collect()
+
             cont = -1
             separate = 0
             # create the applet with little hboxes containing each info checked in the preferences
@@ -139,7 +143,9 @@ class pycentrinoApplet(gnome.applet.Applet):
                         tmp = gtk.Label(self.info[i])
                         tmp.modify_font(fd)
                         self.box.get_children()[cont].get_children()[0].pack_start(tmp)
-        
+
+        # added to prevent memory leaks
+        #gc.collect()
         self.applet.show_all()
         return 1
 
@@ -466,7 +472,7 @@ if len(sys.argv) > 1 and sys.argv[1] == "run-in-window":
     app.reparent(main_window)
     main_window.show_all()
     gtk.main()
-    sys.exit()
+    #sys.exit()
 
 if __name__ == '__main__':
     gnome.applet.bonobo_factory("OAFIID:GNOME_PycentrinoApplet_Factory",
